@@ -142,15 +142,18 @@ define('io.ox/tours/main',
             },
             {
                 title: gt('The list'),
-                placement: 'left',
+                placement: 'top', // see bug #34010
                 target: function () { return $('.list-view:visible')[0]; },
-                content: gt('Use the list to select an object, show its contents or activate functions.')
+                content: gt('Use the list to select an object, show its contents or activate functions.'),
+                yOffset: 50,
+                xOffset: 200
             },
             {
                 title: gt('The Detail view'),
                 placement: 'left',
                 target: function () { return $('.mail-detail-pane:visible')[0]; },
-                content: gt('The Detail view displays an object\'s content. Depending on the app, further functions for organizing objects can be found in the Detail view.')
+                content: gt('The Detail view displays an object\'s content. Depending on the app, further functions for organizing objects can be found in the Detail view.'),
+                xOffset: 100
             },
             {
                 title: gt('Further information'),
@@ -294,7 +297,9 @@ define('io.ox/tours/main',
                 placement: 'bottom', /* Check target */
                 target: function () { return $('.dropdown.grid-options.toolbar-item.pull-right:visible')[0]; },
                 content: gt('To sort the E-Mails, click on Sort by. Select a sort criteria.'),
-                xOffset: -15
+                xOffset: -230, // see bug #34010
+                arrowOffset: 230,
+                width: 260
             },
             {
                 title: gt('Selecting a view'),
@@ -302,14 +307,14 @@ define('io.ox/tours/main',
                 target: function () { return $('.classic-toolbar .pull-right:visible')[0]; },
                 content: gt('To choose between the different views. click on View in the toolbar. Select a menu entry in the layout.'),
                 xOffset: -15
-            }, 
+            },
             {
                 title: gt('Opening an E-Mail in a separate window'),
-                placement: 'right',
+                placement: 'top', // see bug #34125
                 target: function () { return $('.list-view:visible')[0]; },
                 content: gt('If double-clicking on an E-Mail in the list, the E-Mail is opened in a separate window.'),
-                xOffset: -15
-            }, 
+                yOffset: 110  // see bug #34125
+            },
             {
                 title: gt('Reading E-Mail conversations'),
                 placement: 'left',
@@ -704,7 +709,7 @@ define('io.ox/tours/main',
             },
             {
                 title: gt('Editing multiple tasks'),
-                placement: 'right',
+                placement: 'bottom', // preventive fixed along with bug #34125
                 target: function () { return $('.vgrid-scrollpane-container:visible')[0]; },
                 //target: function () { return $('abs.vgrid-scrollpane:visible')[0]; },
                 content: gt('To edit multiple tasks at once, enable the checkboxes at the left side of the tasks. If the checkboxes are not displayed, click on View > Checkboxes on the right side of the toolbar.'),
@@ -758,6 +763,9 @@ define('io.ox/tours/main',
         id: 'tours',
         index: 1000,
         run: function () {
+            if (_.device('smartphone')) {//tablets are fine just disable phones
+                return $.when();
+            }
 
             ox.load(['io.ox/tours/main', 'settings!io.ox/tours']).done(function (tours, tourSettings) {
                 var disableTour = tourSettings.get('server/disableTours'),
